![NBAFlow logo](./docs/assets/imgs/header-readme.png)

<div align="center">  

  [![PyPI](https://img.shields.io/pypi/v/nbaflow?color=orange)](https://pypi.org/project/nbaflow/)
  ![PyPI - Downloads](https://img.shields.io/pypi/dm/nbaflow?color=orange)
  ![PyPI - Status](https://img.shields.io/pypi/status/nbaflow?color=orange)

</div>

<div align="center">
  <strong>:basketball: Helping users to get and analyse NBA data using the <a href="https://github.com/swar/nba_api"> nba_api</a> Python package :basketball:</strong>
</div>
<br/>


> **Note**
> This project is under construction. Soon as possible it will be ready to go.